summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteonlinestatusmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteonlinestatusmanager.h')
-rw-r--r--kopete/libkopete/kopeteonlinestatusmanager.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/kopete/libkopete/kopeteonlinestatusmanager.h b/kopete/libkopete/kopeteonlinestatusmanager.h
index 7a52d8c2..0ce2f983 100644
--- a/kopete/libkopete/kopeteonlinestatusmanager.h
+++ b/kopete/libkopete/kopeteonlinestatusmanager.h
@@ -39,9 +39,10 @@ namespace Kopete
*
* @author Olivier Goffart
*/
-class KOPETE_EXPORT OnlineStatusManager : public QObject
+class KOPETE_EXPORT OnlineStatusManager : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
static OnlineStatusManager* self();
~OnlineStatusManager();
@@ -53,9 +54,9 @@ public:
*
* Idle is the status used for auto-away
*
- * Status number are organised so that make a tree.
+ * tqStatus number are organised so that make a tree.
*/
//please be carrefull when modifying values of status. read comment in onlineStatus()
enum Categories
{
Idle=1<<8, ExtendedAway=1<<9 , Invisible=1<<10,
@@ -105,23 +106,23 @@ public:
void registerOnlineStatus(const OnlineStatus& status, const TQString &caption, unsigned int categories=0x00 , unsigned int options=0x0);
/**
* insert "setStatus" actions from the given account to the specified actionMenu.
* (actions have that menu as parent TQObject)
* they are connected to the Account::setOnlineStatus signal
*
* Items are stored by status height.
*
* @param account the account
* @param parent the ActionMenu where action are inserted
*/
- void createAccountStatusActions( Account *account , KActionMenu *parent);
+ void createAccountStatusActions( Account *account , KActionMenu *tqparent);
/**
* return the status of the @p protocol which is in the category @p category
*
* If no status has been registered in this category, return the one in the category which is the most similair
*/
- OnlineStatus onlineStatus(Protocol *protocol, Categories category) const;
+ OnlineStatus onlinetqStatus(Protocol *protocol, Categories category) const;
private:
friend class OnlineStatus;
@@ -151,8 +152,9 @@ private:
class OnlineStatusAction : public KAction
{
Q_OBJECT
+ TQ_OBJECT
public:
- OnlineStatusAction ( const OnlineStatus& status, const TQString &text, const TQIconSet &pix, TQObject *parent=0, const char *name=0);
+ OnlineStatusAction ( const OnlineStatus& status, const TQString &text, const TQIconSet &pix, TQObject *tqparent=0, const char *name=0);
signals:
void activated( const Kopete::OnlineStatus& status );
private slots:
@@ -53,9 +54,9 @@ public:
*/
- //please be carrefull when modifying values of status. read comment in onlineStatus()
+ //please be carrefull when modifying values of status. read comment in onlinetqStatus()
enum Categories
{
@@ -105,23 +106,23 @@ public:
void registerOnlineStatus(const OnlineStatus& status, const TQString &caption, unsigned int categories=0x00 , unsigned int options=0x0);
/**
- * insert "setStatus" actions from the given account to the specified actionMenu.
- * (actions have that menu as parent TQObject)
+ * insert "settqStatus" actions from the given account to the specified actionMenu.
+ * (actions have that menu as tqparent TQObject)
* they are connected to the Account::setOnlineStatus signal
*
@@ -105,23 +106,23 @@ public:
*
* @param account the account
- * @param parent the ActionMenu where action are inserted
+ * @param tqparent the ActionMenu where action are inserted
*/